@@ -553,6 +553,9 @@ async def get_or_create_redis_instance_from_django_instance(
     )
 
     django_instance_model = django_instance.__class__
+    print('Foreign', django_instance_model, django_instance.id)
+
+    print(not redis_instance)
     if not redis_instance:
         redis_dict = await django_instance_to_redis_params(
             redis_root,
@@ -565,8 +568,5 @@ async def get_or_create_redis_instance_from_django_instance(
             django_id=django_instance.id,
             **redis_dict
         )
-    else:
-        redis_instance = redis_instance[0]
-
 
     return redis_instance
